@@ -185,15 +185,15 @@ AUTHORS:
 
 - Christian Stump (2015): initial version
 """
-#*****************************************************************************
+# ****************************************************************************
 #       Copyright (C) 2011-2016 Christian Stump <christian.stump at gmail.com>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 2 of the License, or
 # (at your option) any later version.
-#                  http://www.gnu.org/licenses/
-#*****************************************************************************
+#                  https://www.gnu.org/licenses/
+# ****************************************************************************
 
 from sage.misc.cachefunc import cached_method, cached_function
 from sage.misc.misc_c import prod
@@ -205,7 +205,8 @@ from sage.combinat.root_system.reflection_group_element import ComplexReflection
 from sage.sets.family import Family
 from sage.structure.unique_representation import UniqueRepresentation
 from sage.groups.perm_gps.permgroup import PermutationGroup_generic
-from sage.rings.all import ZZ, QQ
+from sage.rings.integer_ring import ZZ
+from sage.rings.rational_field import QQ
 from sage.matrix.all import Matrix, identity_matrix
 from sage.structure.element import is_Matrix
 from sage.interfaces.gap3 import gap3
@@ -224,6 +225,7 @@ class ComplexReflectionGroup(UniqueRepresentation, PermutationGroup_generic):
 
         :func:`ReflectionGroup`
     """
+
     def __init__(self, W_types, index_set=None, hyperplane_index_set=None, reflection_index_set=None):
         r"""
         TESTS::
@@ -235,26 +237,26 @@ class ComplexReflectionGroup(UniqueRepresentation, PermutationGroup_generic):
         W_components = []
         reflection_type = []
         for W_type in W_types:
-            if W_type == (1,1,1):
+            if W_type == (1, 1, 1):
                 raise ValueError("the one element group is not considered a reflection group")
             elif W_type in ZZ:
-                call_str = 'ComplexReflectionGroup(%s)'%W_type
-            elif isinstance(W_type,CartanMatrix):
-                call_str = 'PermRootGroup(IdentityMat(%s),%s)'%(W_type._rank,str(W_type._M._gap_()))
+                call_str = 'ComplexReflectionGroup(%s)' % W_type
+            elif isinstance(W_type, CartanMatrix):
+                call_str = 'PermRootGroup(IdentityMat(%s),%s)' % (W_type._rank, str(W_type._M._gap_()))
             elif is_Matrix(W_type):
-                call_str = 'PermRootGroup(IdentityMat(%s),%s)'%(W_type._rank,str(W_type._gap_()))
-            elif W_type in ZZ or ( isinstance(W_type, tuple) and len(W_type) == 3 ):
-                call_str = 'ComplexReflectionGroup%s'%str(W_type)
+                call_str = 'PermRootGroup(IdentityMat(%s),%s)' % (W_type._rank, str(W_type._gap_()))
+            elif W_type in ZZ or (isinstance(W_type, tuple) and len(W_type) == 3):
+                call_str = 'ComplexReflectionGroup%s' % str(W_type)
             else:
                 if W_type[0] == "I":
-                    call_str = 'CoxeterGroup("I",2,%s)'%W_type[1]
+                    call_str = 'CoxeterGroup("I",2,%s)' % W_type[1]
                 else:
-                    call_str = 'CoxeterGroup("%s",%s)'%W_type
+                    call_str = 'CoxeterGroup("%s",%s)' % W_type
 
             W_components.append(gap3(call_str))
             X = list(W_components[-1].ReflectionType())
             if len(X) > 1:
-                raise ValueError("input data %s is invalid"%W_type)
+                raise ValueError("input data %s is invalid" % W_type)
             X = X[0]
             type_dict = {}
             type_dict["series"] = X.series.sage()
@@ -302,14 +304,14 @@ class ComplexReflectionGroup(UniqueRepresentation, PermutationGroup_generic):
             self._index_set = tuple(l_set)
         else:
             if len(self._index_set) != len(l_set):
-                raise ValueError("the given index set (= %s) does not have the right size"%self._index_set.values())
+                raise ValueError("the given index set (= %s) does not have the right size" % self._index_set.values())
         self._index_set_inverse = {i: ii for ii,i in enumerate(self._index_set)}
         Nstar_set = list(range(1, self.number_of_reflection_hyperplanes() + 1))
         if self._hyperplane_index_set is None:
             self._hyperplane_index_set = tuple(Nstar_set)
         else:
             if len(self._hyperplane_index_set) != len(Nstar_set):
-                raise ValueError("the given hyperplane index set (= %s) does not have the right size"%self._index_set.values())
+                raise ValueError("the given hyperplane index set (= %s) does not have the right size" % self._index_set.values())
         self._hyperplane_index_set_inverse = {i: ii for ii,i in enumerate(self._hyperplane_index_set)}
 
         N_set = list(range(1, self.number_of_reflections() + 1))
@@ -317,7 +319,7 @@ class ComplexReflectionGroup(UniqueRepresentation, PermutationGroup_generic):
             self._reflection_index_set = tuple(N_set)
         else:
             if len(self._reflection_index_set) != len(N_set):
-                raise ValueError("the given reflection index set (= %s) does not have the right size"%self._index_set.values())
+                raise ValueError("the given reflection index set (= %s) does not have the right size" % self._index_set.values())
         self._reflection_index_set_inverse = {i: ii for ii,i in enumerate(self._reflection_index_set)}
 
     def _irrcomp_repr_(self,W_type):
@@ -363,7 +365,7 @@ class ComplexReflectionGroup(UniqueRepresentation, PermutationGroup_generic):
             type_str += self._irrcomp_repr_(W_type)
             type_str += ' x '
         type_str = type_str[:-3]
-        return 'Reducible complex reflection group of rank %s and type %s'%(self._rank,type_str)
+        return 'Reducible complex reflection group of rank %s and type %s' % (self._rank, type_str)
 
     def __iter__(self):
         r"""
@@ -1388,7 +1390,7 @@ class ComplexReflectionGroup(UniqueRepresentation, PermutationGroup_generic):
             [[[1, 2, 1], [2, 1, 2]], [[1, 3], [3, 1]], [[2, 3, 2], [3, 2, 3]]]
         """
         if self.is_real():
-            return super(ComplexReflectionGroup,self).braid_relations()
+            return super().braid_relations()
         else:
             return self._gap_group.BraidRelations().sage()
 
@@ -1413,7 +1415,7 @@ class ComplexReflectionGroup(UniqueRepresentation, PermutationGroup_generic):
         if not self.is_irreducible():
             return sum([W.fundamental_invariants() for W in self.irreducible_components() ],tuple())
 
-        I = [ str(p) for p in gap3('List(Invariants(%s),x->ApplyFunc(x,List([0..%s],i->Mvp(SPrint("x",i)))))'%(self._gap_group._name,self.rank()-1)) ]
+        I = [ str(p) for p in gap3('List(Invariants(%s),x->ApplyFunc(x,List([0..%s],i->Mvp(SPrint("x",i)))))' % (self._gap_group._name, self.rank()-1)) ]
         P = PolynomialRing(QQ,['x%s'%i for i in range(self.rank())])
         x = P.gens()
         for i in range(len(I)):
@@ -1909,7 +1911,7 @@ class ComplexReflectionGroup(UniqueRepresentation, PermutationGroup_generic):
             24
         """
         if chi is None:
-            return super(ComplexReflectionGroup, self).coxeter_number()
+            return super().coxeter_number()
 
         G = self.gens()
         cox_chi = 0
@@ -2028,6 +2030,7 @@ class ComplexReflectionGroup(UniqueRepresentation, PermutationGroup_generic):
                 assert w in self.parent().conjugacy_classes_representatives()
                 return w.reflection_length(in_unitary_group=in_unitary_group)
 
+
 class IrreducibleComplexReflectionGroup(ComplexReflectionGroup):
 
     def _repr_(self):
@@ -2042,7 +2045,7 @@ class IrreducibleComplexReflectionGroup(ComplexReflectionGroup):
             Irreducible complex reflection group of rank 4 and type G(3,1,4)
         """
         type_str = self._irrcomp_repr_(self._type[0])
-        return 'Irreducible complex reflection group of rank %s and type %s'%(self._rank,type_str)
+        return 'Irreducible complex reflection group of rank %s and type %s' % (self._rank, type_str)
 
     class Element(ComplexReflectionGroup.Element):
 
@@ -2200,6 +2203,7 @@ class IrreducibleComplexReflectionGroup(ComplexReflectionGroup):
                         return True
             return False
 
+
 def multi_partitions(n, S, i=None):
     r"""
     Return all vectors as lists of the same length as ``S`` whose
@@ -2238,6 +2242,7 @@ def multi_partitions(n, S, i=None):
     coeffs = coeffs1 + coeffs2
     return coeffs
 
+
 @cached_function
 def power(f, k):
     r"""
