@@ -22,7 +22,7 @@ from sage.structure.unique_representation import UniqueRepresentation
 from sage.libs.symmetrica.all import hall_littlewood
 from . import sfa
 import sage.combinat.partition
-from sage.matrix.all import matrix
+from sage.matrix.constructor import matrix
 from sage.categories.morphism import SetMorphism
 from sage.categories.homset import Hom
 from sage.rings.rational_field import QQ
@@ -39,6 +39,8 @@ QQt = QQ['t'].fraction_field()
 # TODO: optimize! which is the fastest way of computing HL's and kostka-polynomials?
 # Qp basis is computed using symmetrica, while P basis is computed using rigged
 # configurations
+
+
 class HallLittlewood(UniqueRepresentation):
     r"""
     The family of Hall-Littlewood symmetric function bases.
@@ -58,6 +60,7 @@ class HallLittlewood(UniqueRepresentation):
         sage: SymmetricFunctions(QQ['t'].fraction_field()).hall_littlewood()
         Hall-Littlewood polynomials over Fraction Field of Univariate Polynomial Ring in t over Rational Field
     """
+
     def __repr__(self):
         r"""
         A string representing the family of Hall-Littlewood symmetric function bases
@@ -66,14 +69,14 @@ class HallLittlewood(UniqueRepresentation):
 
         - a string representing the class
 
-        EXAMPLES ::
+        EXAMPLES::
 
             sage: SymmetricFunctions(QQ).hall_littlewood(1)
             Hall-Littlewood polynomials with t=1 over Rational Field
         """
-        return self._name+ " over %s"%self._sym.base_ring()
+        return self._name + " over %s" % self._sym.base_ring()
 
-    def __init__(self, Sym, t = 't'):
+    def __init__(self, Sym, t='t'):
         """
         Initialize ``self``.
 
@@ -102,7 +105,7 @@ class HallLittlewood(UniqueRepresentation):
 
         - returns the ring of symmetric functions
 
-        EXAMPLES ::
+        EXAMPLES::
 
             sage: HL = SymmetricFunctions(FractionField(QQ['t'])).hall_littlewood()
             sage: HL.symmetric_function_ring()
@@ -123,7 +126,7 @@ class HallLittlewood(UniqueRepresentation):
 
         The base ring of the symmetric functions.
 
-        EXAMPLES ::
+        EXAMPLES::
 
             sage: HL = SymmetricFunctions(QQ['t'].fraction_field()).hall_littlewood(t=1)
             sage: HL.base_ring()
@@ -344,6 +347,7 @@ class HallLittlewood(UniqueRepresentation):
         """
         return HallLittlewood_qp(self)
 
+
 class HallLittlewood_generic(sfa.SymmetricFunctionAlgebra_generic):
     def __init__(self, hall_littlewood):
         r"""
@@ -365,8 +369,8 @@ class HallLittlewood_generic(sfa.SymmetricFunctionAlgebra_generic):
         s = self.__class__.__name__[15:].capitalize()
         sfa.SymmetricFunctionAlgebra_generic.__init__(
             self, hall_littlewood._sym,
-            basis_name = "Hall-Littlewood " + s + hall_littlewood._name_suffix,
-            prefix = "HL"+s)
+            basis_name="Hall-Littlewood " + s + hall_littlewood._name_suffix,
+            prefix="HL" +s)
         self.t = hall_littlewood.t
         self._sym = hall_littlewood._sym
         self._hall_littlewood = hall_littlewood
@@ -407,7 +411,8 @@ class HallLittlewood_generic(sfa.SymmetricFunctionAlgebra_generic):
             sage: P(s[2,1])
             6*HLP[1, 1, 1] + HLP[2, 1]
         """
-        return self._from_cache(x, self._s_cache, self._s_to_self_cache, t = self.t)
+        return self._from_cache(x, self._s_cache, self._s_to_self_cache,
+                                t=self.t)
 
     def _self_to_s(self, x):
         r"""
@@ -435,7 +440,8 @@ class HallLittlewood_generic(sfa.SymmetricFunctionAlgebra_generic):
             sage: s(P[2,1])
             -6*s[1, 1, 1] + s[2, 1]
         """
-        return self._s._from_cache(x, self._s_cache, self._self_to_s_cache, t = self.t)
+        return self._s._from_cache(x, self._s_cache, self._self_to_s_cache,
+                                   t=self.t)
 
     def transition_matrix(self, basis, n):
         r"""
@@ -532,7 +538,7 @@ class HallLittlewood_generic(sfa.SymmetricFunctionAlgebra_generic):
 
         - returns the class of Hall-Littlewood bases
 
-        EXAMPLES ::
+        EXAMPLES::
 
             sage: HLP = SymmetricFunctions(FractionField(QQ['t'])).hall_littlewood(1).P()
             sage: HLP.hall_littlewood_family()
@@ -545,7 +551,7 @@ class HallLittlewood_generic(sfa.SymmetricFunctionAlgebra_generic):
         Methods for elements of a Hall-Littlewood basis that are common to all bases.
         """
 
-        def expand(self, n, alphabet = 'x'):
+        def expand(self, n, alphabet='x'):
             r"""
             Expands the symmetric function as a symmetric polynomial in ``n`` variables.
 
@@ -577,7 +583,7 @@ class HallLittlewood_generic(sfa.SymmetricFunctionAlgebra_generic):
                 x^2
             """
             s = self.parent().realization_of().schur()
-            return s(self).expand(n, alphabet = alphabet)
+            return s(self).expand(n, alphabet=alphabet)
 
         def scalar(self, x, zee=None):
             r"""
@@ -618,7 +624,7 @@ class HallLittlewood_generic(sfa.SymmetricFunctionAlgebra_generic):
             s_x = s(x)
             return s_self.scalar(s_x, zee)
 
-        def scalar_hl(self, x, t = None):
+        def scalar_hl(self, x, t=None):
             r"""
             Returns the Hall-Littlewood (with parameter ``t``) scalar product
             of ``self`` and ``x``.
@@ -661,8 +667,9 @@ class HallLittlewood_generic(sfa.SymmetricFunctionAlgebra_generic):
             if t is None:
                 t = parent.t
             p = parent.realization_of().power()
-            f = lambda part1, part2: part1.centralizer_size(t = t)
-            return parent._apply_multi_module_morphism(p(self),p(x),f,orthogonal=True)
+            f = lambda part1, part2: part1.centralizer_size(t=t)
+            return parent._apply_multi_module_morphism(p(self), p(x), f,
+                                                       orthogonal=True)
 
 
 ###########
@@ -794,12 +801,11 @@ class HallLittlewood_p(HallLittlewood_generic):
             sage: l(HLP._s_to_self_cache[2])
             [([1, 1], [([1, 1], 1)]), ([2], [([1, 1], t), ([2], 1)])]
         """
-        self._invert_morphism(n, QQt, self._self_to_s_cache, \
-                              self._s_to_self_cache, to_self_function = self._s_to_self_base, \
+        self._invert_morphism(n, QQt, self._self_to_s_cache,
+                              self._s_to_self_cache, to_self_function=self._s_to_self_base,
                               upper_triangular=True, ones_on_diagonal=True)
 
 
-
 ###########
 # Q basis #
 ###########
@@ -844,9 +850,10 @@ class HallLittlewood_q(HallLittlewood_generic):
         # temporary until Hom(GradedHopfAlgebrasWithBasis work better)
         category = sage.categories.all.ModulesWithBasis(self.base_ring())
 
-        phi = self.module_morphism(diagonal = self._P._q_to_p_normalization, codomain = self._P, category = category)
+        phi = self.module_morphism(diagonal=self._P._q_to_p_normalization,
+                                   codomain=self._P, category=category)
         self._P.register_coercion(phi)
-        self   .register_coercion(~phi)
+        self.register_coercion(~phi)
 
     def _p_to_q_normalization(self, m):
         r"""
@@ -884,7 +891,6 @@ class HallLittlewood_q(HallLittlewood_generic):
         return coeff
 
 
-
 ############
 # Qp basis #
 ############
@@ -996,10 +1002,12 @@ class HallLittlewood_qp(HallLittlewood_generic):
             sage: l(HLQp._self_to_s_cache[2])
             [([1, 1], [([1, 1], 1), ([2], t)]), ([2], [([2], 1)])]
         """
-        self._invert_morphism(n, QQt, self._self_to_s_cache, \
-                              self._s_to_self_cache, to_other_function = self._to_s, \
+        self._invert_morphism(n, QQt, self._self_to_s_cache,
+                              self._s_to_self_cache,
+                              to_other_function=self._to_s,
                               lower_triangular=True, ones_on_diagonal=True)
 
+
 # Unpickling backward compatibility
 sage.misc.persist.register_unpickle_override('sage.combinat.sf.hall_littlewood', 'HallLittlewoodElement_p', HallLittlewood_p.Element)
 sage.misc.persist.register_unpickle_override('sage.combinat.sf.hall_littlewood', 'HallLittlewoodElement_q', HallLittlewood_q.Element)
