@@ -420,10 +420,11 @@ def minimize(func, x0, gradient=None, hessian=None, algorithm="default",
                 hessian=lambda p: [[a(*p) for a in row] for row in hess_fast]
                 from scipy import dot
                 hessian_p=lambda p,v: dot(numpy.array(hessian(p)),v)
-                min = optimize.fmin_ncg(f, [float(_) for _ in x0], fprime=gradient, \
+                min = optimize.fmin_ncg(f, [float(_) for _ in x0], fprime=gradient,
                       fhess=hessian, fhess_p=hessian_p, disp=verbose, **args)
     return vector(RDF, min)
 
+
 def minimize_constrained(func,cons,x0,gradient=None,algorithm='default', **args):
     r"""
     Minimize a function with constraints.
