@@ -87,16 +87,17 @@ Classes and Methods
 ===================
 """
 
-#*****************************************************************************
+# ****************************************************************************
 # Copyright (C) 2015 Daniel Krenn <dev@danielkrenn.at>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 2 of the License, or
 # (at your option) any later version.
-#                  http://www.gnu.org/licenses/
-#*****************************************************************************
+#                  https://www.gnu.org/licenses/
+# ****************************************************************************
 
+import sage.rings.abc
 from .ring import SymbolicRing, SR
 from sage.categories.pushout import ConstructionFunctor
 from sage.structure.factory import UniqueFactory
@@ -224,7 +225,6 @@ class SymbolicSubringFactory(UniqueFactory):
         vars = tuple(sorted(iter(SR(v) for v in vars), key=str))
         return (cls, vars), kwds
 
-
     def create_object(self, version, key, **kwds):
         r"""
         Create an object from the given arguments.
@@ -275,14 +275,13 @@ class GenericSymbolicSubring(SymbolicRing):
             ...
             ValueError: Invalid variables: 0, I, pi, sqrt(2)
         """
-        super(GenericSymbolicSubring, self).__init__()
+        super().__init__()
         self._vars_ = set(vars)
         if not all(v.is_symbol() for v in self._vars_):
             raise ValueError('Invalid variables: {}'.format(
                 ', '.join(str(v) for v in sorted(self._vars_, key=str)
                           if not v.is_symbol())))
 
-
     def _repr_variables_(self):
         r"""
         Return a representation string of the variables.
@@ -309,7 +308,6 @@ class GenericSymbolicSubring(SymbolicRing):
             s = 'the variables '
         return s + ', '.join(str(v) for v in sorted(self._vars_, key=str))
 
-
     def has_valid_variable(self, variable):
         r"""
         Return whether the given ``variable`` is valid in this subring.
@@ -332,7 +330,6 @@ class GenericSymbolicSubring(SymbolicRing):
         """
         raise NotImplementedError('Not implemented in this abstract base class')
 
-
     def _element_constructor_(self, x):
         r"""
         Creates the element of this subring specified by the input ``x``.
@@ -358,14 +355,13 @@ class GenericSymbolicSubring(SymbolicRing):
             ...
             TypeError: x is not contained in Symbolic Subring accepting the variable a
         """
-        expression = super(GenericSymbolicSubring, self)._element_constructor_(x)
-        assert(expression.parent() is self)
+        expression = super()._element_constructor_(x)
+        assert expression.parent() is self
         if not all(self.has_valid_variable(var)
                    for var in expression.variables()):
             raise TypeError('%s is not contained in %s' % (x, self))
         return expression
 
-
     def _coerce_map_from_(self, P):
         r"""
         Return whether ``P`` coerces into this symbolic subring.
@@ -411,9 +407,9 @@ class GenericSymbolicSubring(SymbolicRing):
             # Workaround; can be deleted once #19231 is fixed
             return False
 
-        from sage.rings.all import RLF, CLF, AA, QQbar, InfinityRing
-        from sage.rings.real_mpfi import is_RealIntervalField
-        from sage.rings.complex_interval_field import is_ComplexIntervalField
+        from sage.rings.infinity import InfinityRing
+        from sage.rings.qqbar import AA, QQbar
+        from sage.rings.real_lazy import RLF, CLF
 
         if isinstance(P, type):
             return SR._coerce_map_from_(P)
@@ -425,7 +421,8 @@ class GenericSymbolicSubring(SymbolicRing):
             return True
 
         elif (P is InfinityRing or
-              is_RealIntervalField(P) or is_ComplexIntervalField(P)):
+              isinstance(P, (sage.rings.abc.RealIntervalField,
+                             sage.rings.abc.ComplexIntervalField))):
             return True
 
         elif P._is_numerical():
@@ -517,7 +514,6 @@ class GenericSymbolicSubringFunctor(ConstructionFunctor):
 
     _repr_type_ = 'generic'
 
-
     def __init__(self, vars):
         r"""
         See :class:`GenericSymbolicSubringFunctor` for details.
@@ -530,8 +526,7 @@ class GenericSymbolicSubringFunctor(ConstructionFunctor):
         """
         self.vars = set(vars)
         from sage.categories.rings import Rings
-        super(ConstructionFunctor, self).__init__(Rings(), Rings())
-
+        super().__init__(Rings(), Rings())
 
     def _repr_variables_(self):
         r"""
@@ -550,7 +545,6 @@ class GenericSymbolicSubringFunctor(ConstructionFunctor):
         """
         return ', '.join(str(v) for v in sorted(self.vars, key=str))
 
-
     def _repr_(self):
         r"""
         Return a representation string of this functor.
@@ -573,7 +567,6 @@ class GenericSymbolicSubringFunctor(ConstructionFunctor):
             self._repr_type_, ' ' if self._repr_type_ else '',
             self._repr_variables_() if self.vars else 'no variable')
 
-
     def merge(self, other):
         r"""
         Merge this functor with ``other`` if possible.
@@ -661,7 +654,6 @@ class SymbolicSubringAcceptingVars(GenericSymbolicSubring):
         return 'Symbolic Subring accepting %s' % \
             (self._repr_variables_())
 
-
     def has_valid_variable(self, variable):
         r"""
         Return whether the given ``variable`` is valid in this subring.
@@ -687,7 +679,6 @@ class SymbolicSubringAcceptingVars(GenericSymbolicSubring):
         """
         return SR(variable) in self._vars_
 
-
     def construction(self):
         r"""
         Return the functorial construction of this symbolic subring.
@@ -705,7 +696,6 @@ class SymbolicSubringAcceptingVars(GenericSymbolicSubring):
         """
         return (SymbolicSubringAcceptingVarsFunctor(self._vars_), SR)
 
-
     def _coerce_map_from_(self, P):
         r"""
         Return whether ``P`` coerces into this symbolic subring.
@@ -730,8 +720,7 @@ class SymbolicSubringAcceptingVars(GenericSymbolicSubring):
         """
         if isinstance(P, SymbolicSubringAcceptingVars):
             return self._vars_ >= P._vars_
-        return super(SymbolicSubringAcceptingVars, self)._coerce_map_from_(P)
-
+        return super()._coerce_map_from_(P)
 
     def _an_element_(self):
         r"""
@@ -758,7 +747,6 @@ class SymbolicSubringAcceptingVarsFunctor(GenericSymbolicSubringFunctor):
 
     _repr_type_ = 'accepting'
 
-
     def merge(self, other):
         r"""
         Merge this functor with ``other`` if possible.
@@ -845,7 +833,6 @@ class SymbolicSubringRejectingVars(GenericSymbolicSubring):
         return 'Symbolic Subring rejecting %s' % \
             (self._repr_variables_())
 
-
     def has_valid_variable(self, variable):
         r"""
         Return whether the given ``variable`` is valid in this subring.
@@ -871,7 +858,6 @@ class SymbolicSubringRejectingVars(GenericSymbolicSubring):
         """
         return SR(variable) not in self._vars_
 
-
     def construction(self):
         r"""
         Return the functorial construction of this symbolic subring.
@@ -889,7 +875,6 @@ class SymbolicSubringRejectingVars(GenericSymbolicSubring):
         """
         return (SymbolicSubringRejectingVarsFunctor(self._vars_), SR)
 
-
     def _coerce_map_from_(self, P):
         r"""
         Return whether ``P`` coerces into this symbolic subring.
@@ -921,8 +906,7 @@ class SymbolicSubringRejectingVars(GenericSymbolicSubring):
             return self._vars_ <= P._vars_
         elif isinstance(P, SymbolicSubringAcceptingVars):
             return not (self._vars_ & P._vars_)
-        return super(SymbolicSubringRejectingVars, self)._coerce_map_from_(P)
-
+        return super()._coerce_map_from_(P)
 
     def _an_element_(self):
         r"""
@@ -964,7 +948,6 @@ class SymbolicSubringRejectingVarsFunctor(GenericSymbolicSubringFunctor):
 
     _repr_type_ = 'rejecting'
 
-
     def merge(self, other):
         r"""
         Merge this functor with ``other`` if possible.
@@ -995,7 +978,6 @@ class SymbolicSubringRejectingVarsFunctor(GenericSymbolicSubringFunctor):
             if not (self.vars & other.vars):
                 return self
 
-
     def _apply_functor(self, R):
         """
         Apply this functor to the given symbolic ring `R`.
